# lobo_rig

Pin variables for my controllers.

## Installation as a submodule

```bash
poetry add --editable git+ssh://git@github.com/lukasz-lobocki/lobo_rig.git
```

## License

`lobo_rig` was created by Lukasz Lobocki. It is licensed under the terms of the CC0 v1.0 Universal license.

All components used retain their original licenses.

## Credits

`lobo_rig` was created with [cookiecutter](https://cookiecutter.readthedocs.io/en/latest/) and [template](https://github.com/lukasz-lobocki/py-pkgs-cookiecutter).
